Learn R Programming

cyclomort (version 1.0.2)

nwt_morts: Mortality data for Northwest territory boreal woodland caribou.

Description

Mortality data for Northwest territory boreal woodland caribou, anonymized and randomized by year, thereby retaining the multi-seasonal signal without, with grateful acknowledgements to A. Kelly and N. Larter.

Usage

data(nwt_morts)

Arguments

Format

Data frame with 370 rows and the following columns:

id

ID of animal

start

Date of beginning of collaring

end

Date of death or censoring

status

"Mort" or "Cens" (dead or censored)

Examples

Run this code
# NOT RUN {
data(nwt_morts)
require(ggplot2); require(magrittr); require(plyr)
ggplot(nwt_morts %>% arrange(start) %>% mutate(id = factor(id, levels = id)),
aes(x = start, y = id, col = status)) +
  geom_errorbarh(aes(xmin = start, xmax = end))

# }

Run the code above in your browser using DataLab