Learn R Programming

cyclomort (version 1.0.2)

summary.cmfit: Provide a short summary of cmfit (parameter estimates for periodic mortality curves) objects

Description

Provide a short summary of cmfit (parameter estimates for periodic mortality curves) objects

Usage

# S3 method for cmfit
summary(object, date = FALSE, ...)

Arguments

object

a cmfit object

date

logical dictating whether peaks of high mortality are expressed as Dates

...

(not implemented)

Value

a list containing a short summary of the estimates for each parameter along with confidence intervals and AIC

Examples

Run this code
# NOT RUN {
# Simulate data
T.morts1 <- simulate_cycloSurv(1000, period = 365, 
                             meanhazard = 0.3 / 365, 
                             peaks = c(0.25 * 365, 0.75 * 365), 
                             durations = c(0.3 * 365, 0.1 * 365), 
                             weights = c(0.7,0.3), 
                             plotme = FALSE)

# Estimate simulated data
fits <- fit_cyclomort(T.morts1, n.seasons = 2)
fits

# Plot results
plot(fits, nreps = 1000, monthlabs = TRUE)
# NB: `nreps` is for the bootstrap of the confidence interval 
# The default (5000) is slower but smoother

# Actual parameter values from simulated data
attributes(T.morts1)
# }

Run the code above in your browser using DataLab