Learn R Programming

cyclomort (version 1.0.2)

wah_morts: Mortality data for Western Arctic Herd Caribou

Description

Anonymized mortality data on Western Arctic Herd caribou collected by the U.S. National Park Service, Alaska, with grateful acknowledgments to K. Joly.

Usage

data(wah_morts)

Arguments

Format

Data frame with 171 rows and the following columns:

id

ID of animal

start

Date of beginning of collaring

end

Date of death or censoring

fate

One of "dead", or "censored"

Examples

Run this code
# NOT RUN {
data(wah_morts)
require(ggplot2); require(magrittr); require(plyr)
ggplot(wah_morts %>% arrange(start),
aes(x = start, y = id, col = fate)) + 
  geom_errorbarh(aes(xmin = start, xmax = end))

# }

Run the code above in your browser using DataLab